@@ -10,9 +10,17 @@ DayHistory::DayHistory(QWidget *parent) :
     lstExercises = new QListView();
     model = new QStandardItemModel(this);
     lstExercises->setModel(model);
+    connect(lstExercises,SIGNAL(clicked(QModelIndex)),this,SLOT(showInfo(QModelIndex)));
+
     setCentralWidget (lstExercises);
 }
 
+void DayHistory::showInfo(QModelIndex index)
+{
+    hiw = new HistoryInfoWindow(this);
+    hiw->load(index.data().toString());
+    hiw->show();
+}
 
 void DayHistory::load(QString date)
 {
