@@ -90,6 +90,8 @@ void ExerciseWindow::sendClosed()
 
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
+    currentReps = "4";
+
     bool firstTime = false;
     if(exercises.count() == 0)
         firstTime = true;
@@ -98,24 +100,11 @@ void ExerciseWindow::loadExercise(QList<QString> name)
     QDBusConnection::sessionBus().send(lock);
     QList <QString> tmp;
     QList<QString> settings = xml->loadSettings();
-    QString lstReps[3];
+
     settings.removeLast();
     SEC = settings.takeLast().toInt();
     MIN = settings.takeLast().toInt();
 
-    currentReps = settings.takeLast();
-    lstReps[2] = settings.takeLast();
-    lstReps[1] = settings.takeLast();
-    lstReps[0] = settings.takeLast();
-
-    if(currentReps == "Easy")
-        REPS = lstReps[0].toInt();
-    else if(currentReps == "Mid")
-        REPS = lstReps[1].toInt();
-    else
-        REPS = lstReps[2].toInt();
-
-
     SET = settings.takeLast().toInt();
 
     vibrateActive = false; soundActive = false;
@@ -132,9 +121,9 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         tmp.removeFirst();
         currentGroup = tmp.takeFirst();
 
-        set = SET; reps = REPS; min = MIN; sec = SEC;
-        strSet.setNum(SET); strReps.setNum(REPS); strMin.setNum(MIN);  strSec.setNum(SEC);
-        label->setText(currentExercise + "\n Shake when done " + strReps + " reps");
+        set = SET; min = MIN; sec = SEC;
+        strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
+        label->setText(currentExercise + "\n Shake when done set is done.");
         btnShake->setEnabled(true);
         myThread->start(QThread::NormalPriority);
     }
@@ -185,9 +174,9 @@ void ExerciseWindow::setCurrentExercise(QString name)
     currentGroup = tmp.takeFirst();
 
 
-    set = SET; reps = REPS; min = MIN; sec = SEC;
-    strSet.setNum(SET); strReps.setNum(REPS); strMin.setNum(MIN);  strSec.setNum(SEC);
-    label->setText(currentExercise + "\n Shake when done " + strReps + " reps");
+    set = SET; min = MIN; sec = SEC;
+    strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
+    label->setText(currentExercise + "\n Shake when set is done.");
 
     btnShake->setEnabled(true);
     myThread->start(QThread::NormalPriority);
@@ -283,8 +272,7 @@ void ExerciseWindow::updateTime()
         {
             //wait is over
 
-            strReps.setNum(reps);
-            label->setText("Exercise: " + currentExercise +  "\n Shake when done " + strReps + "reps");
+            label->setText("Exercise: " + currentExercise +  "\n Shake when set is done.");
             btnShake->setEnabled(true);
 
 
