@@ -3,13 +3,15 @@
 HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
     QMainWindow(parent)
 {
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+
     QWidget *widget = new QWidget();
-    QVBoxLayout vLayout = new QVBoxLayout();
+    QVBoxLayout *vLayout = new QVBoxLayout();
 
     for(int i = 0; i < 9; i++)
     {
         lblSet[i] = new QLabel();
-        vLayout.addWidget(lblSet[i]);
+        vLayout->addWidget(lblSet[i]);
     }
 
 
@@ -30,7 +32,7 @@ void HistoryInfoWindow::load(QString name)
     list = xml->getHistoryByExercise(name);
 
     for(int i = 0; i < 9; i++)
-        lblSet[i] = "";
+        lblSet[i]->setText("");
 
     while(!list.isEmpty())
     {
