@@ -216,9 +216,15 @@ void InfoWindow::loadExercise(QString name)
 
     i = 0;
     lastText = "";
-    while(weight[i] != "")
+    while(weight[i] != "" && i < 9)
     {
         lastText.append(weight[i] + "x" + reps[i]);
+        if(i < 8)
+        {
+            if(weight[i+1] != "")
+                lastText.append(", ");
+        }
+
     }
 
     lblLast->setText("Last time: " + lastText);
