@@ -193,14 +193,13 @@ QList <QString> XML::getPrograms()
 }
 
 void XML::saveSettings(QString vibrate, QString sound, QString volume,
-                       QString set, QString reps1, QString reps2, QString reps3,
-                       QString currentReps, QString min, QString sec, QString calories)
+                       QString set, QString min, QString sec, QString calories)
 {
     QDomDocument doc( "Settings" );
     QDomElement root = doc.createElement( "setting" );
     doc.appendChild( root );
 
-    root.appendChild(createSettingsNode(doc, vibrate, sound, volume, set, reps1, reps2, reps3, currentReps, min, sec, calories));
+    root.appendChild(createSettingsNode(doc, vibrate, sound, volume, set, min, sec, calories));
 
     QString str = "/home/user/.qexercise";
     QFile file( str + "/settings.xml" );
@@ -246,10 +245,6 @@ QList <QString> XML::loadSettings()
             readInfo.append(e.attribute("sound", ""));
             readInfo.append(e.attribute("volume", ""));
             readInfo.append(e.attribute("set", ""));
-            readInfo.append(e.attribute("reps1", ""));
-            readInfo.append(e.attribute("reps2", ""));
-            readInfo.append(e.attribute("reps3", ""));
-            readInfo.append(e.attribute("currentReps", ""));
             readInfo.append(e.attribute("min", ""));
             readInfo.append(e.attribute("sec", ""));
             readInfo.append(e.attribute("calories", ""));
@@ -262,7 +257,7 @@ QList <QString> XML::loadSettings()
     return readInfo;
 }
 
-void XML::saveDoneEx(QString group, QString name, QString kg, QString currentReps)
+void XML::saveDoneEx(QString group, QString name, QString kg, QString reps, QString status)
 {
     QDate date = QDate::currentDate();
     QString dateString = date.toString("dd-MM-yyyy");
@@ -283,7 +278,7 @@ void XML::saveDoneEx(QString group, QString name, QString kg, QString currentRep
 
     file.close();
 
-    root.appendChild(createHistoryNode(doc, group, name, dateString, kg, currentReps));
+    root.appendChild(createHistoryNode(doc, group, name, dateString, kg, reps, status));
 
     if(!file.open(QIODevice::WriteOnly))
         return ;
@@ -297,39 +292,55 @@ void XML::saveDoneEx(QString group, QString name, QString kg, QString currentRep
 
 }
 
-/*void XML::saveDoneEx(QString group, QString name, QString distance, QString min, QString sec)
+QList <QString> XML::getHistoryByExercise(QString name)
 {
-    QDate date = QDate::currentDate();
-    QString dateString = date.toString("ddMMyy");
+    QList <QString> readInfo;
+    QString lastDate;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/history.xml" );
-    file.open( QIODevice::ReadOnly );
-    doc.setContent( &file );
-
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
+    if( !file.open( QIODevice::ReadOnly ) )
+    {
+        return readInfo;
+    }
+    doc.setContent(&file);
+    file.close();
 
     QDomElement root = doc.documentElement();
     if( root.tagName() != "exercise" )
     {
-        root = doc.createElement( "exercise" );
-        doc.appendChild( root );
+        return readInfo;
     }
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "exercise" )
+        {
+            if(e.attribute("name", "") == name && lastDate == "")
+            {
+                lastDate = e.attribute("date", "");
+            }
 
-    file.close();
+            if(e.attribute("name", "") == name && e.attribute("date", "") == lastDate)
+            {
+                readInfo.append(e.attribute("variable", ""));
+                readInfo.append(e.attribute("reps", ""));
+                readInfo.append(e.attribute("status", ""));
+            }
+        }
 
-    root.appendChild(createHistoryNode(doc, group, name, dateString, kg, currentReps));
+      }
 
-    if(!file.open(QIODevice::WriteOnly))
-        return ;
 
-    QTextStream ts( &file );
-    ts << doc.toString();
+      n = n.nextSibling();
+   }
 
-    file.close();
-
-    return ;
-
-}*/
+    return readInfo;
+}
 
 QList<QString> XML::getDates()
 {
@@ -413,8 +424,6 @@ QList < QList<QString> > XML::getHistoryByDate(QString date)
             {
                 readInfo.append(e.attribute("name", ""));
                 readInfo.append(e.attribute("group", ""));
-                readInfo.append(e.attribute("variable", ""));
-                readInfo.append(e.attribute("reps", ""));
                 list.append(readInfo);
                 readInfo.clear();
             }
@@ -545,7 +554,7 @@ void XML::saveEx(QString name, QString group, QString muscle,
     QDomDocument doc( "Exercises" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/exercises.xml" );
-    file.open( QIODevice::ReadOnly);
+    file.open( QIODevice::ReadWrite);
     doc.setContent( &file );
 
     file.close();
@@ -808,7 +817,6 @@ QList <int> XML::getCaloriesByName(QString name)
 
 void XML::saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat)
 {
-
     QDomDocument doc( "Ingredients" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/ingredients.xml" );
@@ -864,64 +872,6 @@ void XML::saveFood(QString name, QString type, QString kcal, QString protein, QS
    return;
 }
 
-void XML::updateLastWeight(QString name, QString weight, QString status, QString reps)
-{
-    QDomDocument doc( "Exercises" );
-    QString str = "/home/user/.qexercise";
-    QFile file( str + "/exercises.xml" );
-    if( !file.open( QIODevice::ReadWrite ) )
-      return;
-    if( !doc.setContent( &file ) )
-    {
-      file.close();
-      return;
-    }
-    file.remove();
-    file.close();
-
-    QDomElement root = doc.documentElement();
-    if( root.tagName() != "exercises" )
-      return;
-
-    QDomNode n = root.firstChild();
-    while( !n.isNull() )
-    {
-      QDomElement e = n.toElement();
-      if( !e.isNull() )
-      {
-        if( e.tagName() == "exercise" )
-        {
-            if(name == e.attribute( "name", "" ))
-            {
-                if(reps == "Low")
-                {
-                    e.setAttribute("weight-low", weight);
-                    e.setAttribute("status-low", status);
-                }
-                else if(reps == "Mid")
-                {
-                    e.setAttribute("weight-mid", weight);
-                    e.setAttribute("status-mid", status);
-                }
-                else
-                {
-                    e.setAttribute("weight-high", weight);
-                    e.setAttribute("status-high", status);
-                }
-            }
-        }
-      }
-      n = n.nextSibling();
-   }
-
-    file.open( QIODevice::WriteOnly );
-    QTextStream ts( &file );
-    ts << doc.toString();
-    file.close();
-
-    return;
-}
-
 void XML::updateLastDistance(QString name, QString distance, QString min, QString sec, QString status)
 {
     QDomDocument doc( "Cardio" );
@@ -979,12 +929,6 @@ QDomElement XML::createExerciseNode( QDomDocument &d, QString name, QString grou
    cn.setAttribute( "group", group);
    cn.setAttribute( "muscle", muscle );
    cn.setAttribute( "info", info );
-   cn.setAttribute( "weight-low", "0" );
-   cn.setAttribute( "weight-mid", "0" );
-   cn.setAttribute( "weight-high", "0" );
-   cn.setAttribute( "status-low", "ok" );
-   cn.setAttribute( "status-mid", "ok" );
-   cn.setAttribute( "status-high", "ok" );
 
    return cn;
 }
@@ -1031,7 +975,7 @@ QDomElement XML::createFoodNode( QDomDocument &d, QString name, QString type, QS
    return cn;
 }
 
-QDomElement XML::createHistoryNode( QDomDocument &d, QString group, QString name, QString date, QString kg, QString currentReps)
+QDomElement XML::createHistoryNode( QDomDocument &d, QString group, QString name, QString date, QString kg, QString reps, QString status)
 {
    QDomElement cn = d.createElement( "exercise" );
 
@@ -1039,16 +983,14 @@ QDomElement XML::createHistoryNode( QDomDocument &d, QString group, QString name
    cn.setAttribute("name", name);
    cn.setAttribute("date", date);
    cn.setAttribute("variable", kg);
-   cn.setAttribute("reps", currentReps);
-
-   //set? reps?
+   cn.setAttribute("reps", reps);
+   cn.setAttribute("status", status);
 
    return cn;
 }
 
 QDomElement XML::createSettingsNode( QDomDocument &d, QString vibrate, QString sound, QString volume,
-                                QString set, QString reps1, QString reps2, QString reps3, QString currentReps,
-                                QString min, QString sec, QString calories)
+                                QString set, QString min, QString sec, QString calories)
 {
    QDomElement cn = d.createElement( "settings" );
 
@@ -1056,10 +998,6 @@ QDomElement XML::createSettingsNode( QDomDocument &d, QString vibrate, QString s
    cn.setAttribute("sound", sound);
    cn.setAttribute("volume", volume);
    cn.setAttribute( "set", set );
-   cn.setAttribute( "reps1", reps1 );
-   cn.setAttribute( "reps2", reps2 );
-   cn.setAttribute( "reps3", reps3 );
-   cn.setAttribute( "currentReps", currentReps );
    cn.setAttribute( "min", min );
    cn.setAttribute( "sec", sec );
    cn.setAttribute( "calories", calories );
@@ -1109,12 +1047,6 @@ QList<QString> XML::openEx(QString name)
                 readInfo.append(e.attribute("group", ""));
                 readInfo.append(e.attribute("muscle", ""));
                 readInfo.append(e.attribute("info", ""));
-                readInfo.append(e.attribute("weight-low", ""));
-                readInfo.append(e.attribute("weight-mid", ""));
-                readInfo.append(e.attribute("weight-high", ""));
-                readInfo.append(e.attribute("status-low", ""));
-                readInfo.append(e.attribute("status-mid", ""));
-                readInfo.append(e.attribute("status-high", ""));
             }
         }
       }
